<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>QObject</name>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/utils/encryptutils.cpp" line="374"/>
        <source>Cannot generate random number by TPM</source>
        <translation>Falha ao gerar número aleatório pelo TPM</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/utils/encryptutils.cpp" line="377"/>
        <source>No available encrypt algorithm.</source>
        <translation>Nenhum algoritmo de encriptação disponível.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/utils/encryptutils.cpp" line="380"/>
        <source>TPM encrypt failed.</source>
        <translation>Falha na encriptação TPM</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/utils/encryptutils.cpp" line="383"/>
        <source>TPM is locked.</source>
        <translation>TPM bloqueado.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/utils/encryptutils.cpp" line="411"/>
        <source>Confirm encrypt %1?</source>
        <translation>Confirmar criptografia de %1?</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/utils/encryptutils.cpp" line="414"/>
        <source>The current partition is about to be encrypted and cannot be canceled during the encryption process, please confirm the encryption.</source>
        <translation>A partição atual está prestes a ser criptografada e não pode ser cancelada durante o processo de criptografia, confirme a criptografia.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/utils/encryptutils.cpp" line="421"/>
        <source>* After encrypting the partition, the system cannot be rolled back to a lower version, please confirm the encryption</source>
        <translation>* Após criptografar a partição, o sistema não pode ser reembalado para uma versão inferior, confirme a criptografia</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/utils/encryptutils.cpp" line="432"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/utils/encryptutils.cpp" line="433"/>
        <source>Confirm and Reboot</source>
        <translation>Confirmar e Reiniciar</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/utils/encryptutils.cpp" line="434"/>
        <source>Confirm</source>
        <translation>Confirmar</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/utils/encryptutils.cpp" line="444"/>
        <source>Decrypt %1?</source>
        <translation>Descriptografar %1?</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/utils/encryptutils.cpp" line="445"/>
        <source>Decryption can take a long time, so make sure power is connected until the decryption is complete.</source>
        <translation>A descriptografia pode levar um longo tempo, então certifique-se de que a energia está conectada até que a descriptografia seja concluída.</translation>
    </message>
</context>
<context>
    <name>dfmplugin_diskenc::ChgPassphraseDialog</name>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/chgpassphrasedialog.cpp" line="18"/>
        <source>passphrase</source>
        <translation>senha</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/chgpassphrasedialog.cpp" line="20"/>
        <source>PIN</source>
        <translation>PIN</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/chgpassphrasedialog.cpp" line="109"/>
        <source>Recovery key</source>
        <translation>Chave de recuperação</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/chgpassphrasedialog.cpp" line="171"/>
        <source>Validate with %1</source>
        <translation>Validar com %1</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/chgpassphrasedialog.cpp" line="172"/>
        <source>Please input recovery key</source>
        <translation>Introduza a chave de recuperação</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/chgpassphrasedialog.cpp" line="174"/>
        <source>Old %1</source>
        <translation>Antiga %1</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/chgpassphrasedialog.cpp" line="70"/>
        <source>New %1</source>
        <translation>Nova %1</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/chgpassphrasedialog.cpp" line="56"/>
        <source>Modify %1</source>
        <translation>Modificar %1</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/chgpassphrasedialog.cpp" line="67"/>
        <source>Please enter %1 again</source>
        <translation>Por favor introduza %1 novamente</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/chgpassphrasedialog.cpp" line="71"/>
        <source>Repeat %1</source>
        <translation>Repita %1</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/chgpassphrasedialog.cpp" line="77"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/chgpassphrasedialog.cpp" line="78"/>
        <source>Confirm</source>
        <translation>Confirmar</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/chgpassphrasedialog.cpp" line="101"/>
        <source>%1 cannot be empty</source>
        <translation>%1 não pode ser em branco</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/chgpassphrasedialog.cpp" line="115"/>
        <source>Recovery key is not valid!</source>
        <translation>Chave de recuperação inválida!</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/chgpassphrasedialog.cpp" line="140"/>
        <source>At least 8 bits, contains 3 types of A-Z, a-z, 0-9 and symbols</source>
        <translation>Mínimo de 8 bits, contendo 3 tipos de A-Z, a-z, 0-9 e símbolos</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/chgpassphrasedialog.cpp" line="145"/>
        <source>%1 inconsistency</source>
        <translation>inconsistência %1</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/chgpassphrasedialog.cpp" line="177"/>
        <source>Validate with recovery key</source>
        <translation>Validar com chave de recuperação</translation>
    </message>
</context>
<context>
    <name>dfmplugin_diskenc::DecryptParamsInputDialog</name>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/decryptparamsinputdialog.cpp" line="52"/>
        <source>Validate with %1</source>
        <translation>Validar com %1</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/decryptparamsinputdialog.cpp" line="52"/>
        <source>PIN</source>
        <translation>PIN</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/decryptparamsinputdialog.cpp" line="52"/>
        <source>passphrase</source>
        <translation>senha</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/decryptparamsinputdialog.cpp" line="56"/>
        <source>Please input %1 to decrypt device</source>
        <translation>Introduza %1 para desencriptar dispositivo</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/decryptparamsinputdialog.cpp" line="103"/>
        <source>Decrypt device</source>
        <translation>Desencriptar dispositivo</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/decryptparamsinputdialog.cpp" line="51"/>
        <source>Please input recovery key to decrypt device</source>
        <translation>Por favor introduza a chave de recuperação para desencriptar dispositivo</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/decryptparamsinputdialog.cpp" line="57"/>
        <source>Validate with recovery key</source>
        <translation>Validar com chave de recuperação</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/decryptparamsinputdialog.cpp" line="79"/>
        <source>Passphrase</source>
        <translation>Senha</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/decryptparamsinputdialog.cpp" line="81"/>
        <source>Recovery key</source>
        <translation>Chave de recuperação</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/decryptparamsinputdialog.cpp" line="82"/>
        <source>%1 cannot be empty!</source>
        <translation>%1 não pode ser em branco!</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/decryptparamsinputdialog.cpp" line="87"/>
        <source>Recovery key is not valid!</source>
        <translation>Chave de recuperação inválida!</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/decryptparamsinputdialog.cpp" line="111"/>
        <source>Confirm</source>
        <translation>Confirmar</translation>
    </message>
</context>
<context>
    <name>dfmplugin_diskenc::DiskEncryptMenuScene</name>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="148"/>
        <source>Unlock encrypted partition</source>
        <translation>Desbloquear partição encriptada</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="152"/>
        <source>Cancel partition encryption</source>
        <translation>Cancelar encriptação de partição</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="156"/>
        <source>passphrase</source>
        <translation>senha</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="157"/>
        <source>Changing the encryption %1</source>
        <translation>A alterar a encriptação %1</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="161"/>
        <source>Continue partition encryption</source>
        <translation>Continuar criptografia da partição</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="165"/>
        <source>Continue partition decryption</source>
        <translation>Continuar descriptografia da partição</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="169"/>
        <source>Enable partition encryption</source>
        <translation>Ativar encriptação de partição</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="225"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="226"/>
        <source>Cannot resolve passphrase from TPM</source>
        <translation>Falha ao resolver senha pelo TPM</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="248"/>
        <source>PIN error</source>
        <translation>Erro de PIN</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="276"/>
        <source>Change passphrase failed</source>
        <translation>Falha ao mudar senha</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="525"/>
        <source>Unlock device failed</source>
        <translation>Falha ao desbloquear dispositivo</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="526"/>
        <source>Wrong passphrase</source>
        <translation>Senha errada</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="544"/>
        <source>Mount device failed</source>
        <translation>Falha ao montar dispositivo</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="587"/>
        <source>unmount</source>
        <translation>desmontar</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="587"/>
        <source>lock</source>
        <translation>bloquear</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="588"/>
        <source>Encrypt failed</source>
        <translation>Falha ao encriptar</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="589"/>
        <source>Cannot %1 device %2</source>
        <translation>Falha ao %1 dispositivo %2</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="673"/>
        <source>Reboot to continue encrypt</source>
        <translation>Reiniciar para continuar a criptografia</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/menu/diskencryptmenuscene.cpp" line="674"/>
        <source>Reboot to finish decrypt</source>
        <translation>Reiniciar para concluir a descriptografia</translation>
    </message>
</context>
<context>
    <name>dfmplugin_diskenc::EncryptParamsInputDialog</name>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="130"/>
        <source>Unlocked by passphrase</source>
        <translation>Desbloqueado por senha</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="157"/>
        <source>In special cases such as forgetting the password or the encryption hardware is damaged, you can decrypt the encrypted partition with the recovery key, please export it to a non-encrypted partition and keep it in a safe place!</source>
        <translation>Em casos especiais tais como esquecimento de senha ou danos físicos no hardware, pode desencriptar a partição com a chave de recuperação. Exporte-a para uma partição não-encriptada e mantenha-a segura!</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="172"/>
        <source>Please select a non-encrypted partition as the key file export path.</source>
        <translation>Por favor indique uma partição não encriptada como caminho para exportar o ficheiro-chave.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="192"/>
        <source>Passphrase</source>
        <translation>Senha</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="194"/>
        <source>%1 cannot be empty</source>
        <translation>%1 não pode ser em branco</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="225"/>
        <source>%1 inconsistency</source>
        <translation>inconsistência em %1</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="236"/>
        <source>Recovery key export path cannot be empty!</source>
        <translation>O caminho de exportação da chave de recuperação não pode ser vazio!</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="241"/>
        <source>Recovery key export path is not exists!</source>
        <translation>O caminho de exportação da chave de recuperação não existe!</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="248"/>
        <source>Please export to an external device such as a non-encrypted partition or USB flash drive.</source>
        <translation>Por favor exporte para um suporte de dados externo tais como uma partição não-encriptada ou pen USB.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="253"/>
        <source>This partition is read-only, please export to a writable partition</source>
        <translation>Esta partição é de leitura apenas, por favor, exporte para uma partição gravável</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="265"/>
        <source>The partition is encrypted, please export to a non-encrypted partition or external device such as a USB flash drive.</source>
        <translation>A partição encontra-se encriptada, por favor exporte para um suporte de dados externo tais como uma partição não-encriptada ou pen USB.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="421"/>
        <source>TPM is locked and cannot be used for partition encryption. Please cancel the TPM password or choose another unlocking method.</source>
        <translation>TPM está bloqueado e não pode ser usado para criptografia da partição. Por favor, cancele a senha TPM ou escolha outro método de desbloqueio.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="423"/>
        <source>TPM error</source>
        <translation type="unfinished">Erro de TPM</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="426"/>
        <source>TPM status error!</source>
        <translation>Erro no status do TPM!</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="317"/>
        <source>Next</source>
        <translation>Seguinte</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="316"/>
        <source>Please continue to encrypt partition %1</source>
        <translation>Por favor, continue a criptografar a partição %1</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="321"/>
        <source>Previous</source>
        <translation>Anterior</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="320"/>
        <source>Export Recovery Key</source>
        <translation>Exportar chave de recuperação</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="329"/>
        <source>Set %1</source>
        <translation>Definir %1</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="330"/>
        <source>Repeat %1</source>
        <translation>Repetir %1</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="336"/>
        <source>passphrase</source>
        <translation>senha</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="340"/>
        <source>Access to the partition will be unlocked using a passphrase.</source>
        <translation>O acesso à partição será desbloqueado com senha.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="347"/>
        <source>Access to the partition will be unlocked using the TPM security chip and PIN.</source>
        <translation>O acesso à partição será desbloqueado com o chip de segurança TPM e PIN.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="350"/>
        <source>Access to the partition will be automatically unlocked using the TPM security chip, no passphrase checking is required.</source>
        <translation>O acesso à partição será automaticamente desbloqueado com recurso ao chip de segurança TPM, sem necessidade de senhas adicionais.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="332"/>
        <source>Please enter the %1 again</source>
        <translation>Por favor introduza %1 novamente</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="110"/>
        <source>Unlock type</source>
        <translation>Tipo de desbloqueio</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="131"/>
        <source>Use TPM+PIN to unlock on this computer (recommended)</source>
        <translation>Utilizar TPM+PIN para desbloquear este computador (recomendado)</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="132"/>
        <source>Automatic unlocking on this computer by TPM</source>
        <translation>Desbloquear automaticamente este computador com recurso ao TPM</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="220"/>
        <source>At least 8 bits, contains 3 types of A-Z, a-z, 0-9 and symbols</source>
        <translation>Mínimo de 8 bits, contendo 3 tipos de A-Z, a-z, 0-9 e símbolos</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="317"/>
        <source>Confirm encrypt</source>
        <translation>Confirmar criptografia</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptparamsinputdialog.cpp" line="343"/>
        <source>PIN</source>
        <translation>PIN</translation>
    </message>
</context>
<context>
    <name>dfmplugin_diskenc::EncryptProgressDialog</name>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptprogressdialog.cpp" line="54"/>
        <source>Confirm</source>
        <translation type="unfinished">Confirmar</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptprogressdialog.cpp" line="63"/>
        <source>Re-export the recovery key</source>
        <translation>Reexportar a chave de recuperação</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptprogressdialog.cpp" line="67"/>
        <source>*Recovery key saving failed, please re-save the recovery key to a non-encrypted partition and keep it in a safe place!</source>
        <translation>*Falha ao salvar a chave de recuperação, por favor, regrave a chave de recuperação em uma partição não criptografada e mantenha-a em um local seguro!</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptprogressdialog.cpp" line="82"/>
        <source>Error</source>
        <translation type="unfinished">Erro</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptprogressdialog.cpp" line="143"/>
        <source>Recovery key export path cannot be empty!</source>
        <translation type="unfinished">O caminho de exportação da chave de recuperação não pode ser vazio!</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptprogressdialog.cpp" line="148"/>
        <source>Recovery key export path is not exists!</source>
        <translation type="unfinished">O caminho de exportação da chave de recuperação não existe!</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptprogressdialog.cpp" line="154"/>
        <source>This partition is read-only, please export to a writable partition</source>
        <translation>Esta partição é de leitura apenas, por favor, exporte para uma partição gravável</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptprogressdialog.cpp" line="167"/>
        <source>The partition is encrypted, please export to a non-encrypted partition or external device such as a USB flash drive.</source>
        <translation type="unfinished">A partição encontra-se encriptada, por favor exporte para um suporte de dados externo tais como uma partição não-encriptada ou pen USB.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/encryptprogressdialog.cpp" line="183"/>
        <source>Cannot create recovery key file!</source>
        <translation>Não é possível criar um arquivo de chave de recuperação!</translation>
    </message>
</context>
<context>
    <name>dfmplugin_diskenc::EventsHandler</name>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="424"/>
        <source>Preencrypt done</source>
        <translation>Pré-encriptação concluída</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="425"/>
        <source>Device %1 has been preencrypt, please reboot to finish encryption.</source>
        <translation>Dispositivo %1 foi pré encriptado, por favor reinicie para concluir.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="431"/>
        <source>Preencrypt failed</source>
        <translation>Falha ao pré-encriptar</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="432"/>
        <source>Device %1 preencrypt failed, please see log for more information.(%2)</source>
        <translation>Falha ao pré-encriptar %1, verifique o relatório de erro para mais informação. (%2)</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="460"/>
        <source>Wrong passpharse or PIN</source>
        <translation>Senha ou PIN errado</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="496"/>
        <source>passphrase</source>
        <translation>senha</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="499"/>
        <source>PIN</source>
        <translation>PIN</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="506"/>
        <source>Change %1 done</source>
        <translation>Alteração de %1 concluída</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="507"/>
        <source>%1's %2 has been changed</source>
        <translation>%1's %2 foi alterado</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="512"/>
        <source>Change %1 failed</source>
        <translation>Falha ao alterar %1</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="513"/>
        <source>Wrong %1</source>
        <translation>%1 errado</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="518"/>
        <source>Device %1 change %2 failed, please see log for more information.(%3)</source>
        <translation>Falha ao alterar %2 no dispositivo %1, por favor verifique o relatório de erro para mais informação. (%3)</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="180"/>
        <source>Encrypt done</source>
        <translation>Encriptação concluída</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="181"/>
        <source>Device %1 has been encrypted</source>
        <translation>O dispositivo %1 foi encriptado</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="185"/>
        <source>Encrypt failed</source>
        <translation>Falha ao encriptar</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="186"/>
        <source>Device %1 encrypt failed, please see log for more information.(%2)</source>
        <translation>Falha ao encriptar dispositivo %1, por favor verifique o relatório de erro para mais informação. (%2)</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="285"/>
        <source>%1 is under encrypting...</source>
        <translation>Tarefa de encriptação em %1 a decorrer...</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="286"/>
        <source>The encrypting process may have system lag, please minimize the system operation</source>
        <translation>O processo de encriptação pode aumentar o tempo de resposta do sistema, por favor reduza ao minimo necessário a utilização do sistema</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="305"/>
        <source>%1 is under decrypting...</source>
        <translation>Tarefa de desencriptação em %1 a decorrer...</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="306"/>
        <source>The decrypting process may have system lag, please minimize the system operation</source>
        <translation>O processo de desencriptação pode aumentar o tempo de resposta do sistema, por favor reduza ao minimo necessário a utilização do sistema</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="331"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="452"/>
        <source>Decrypt done</source>
        <translation>Desencriptação concluída</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="453"/>
        <source>Device %1 has been decrypted</source>
        <translation>O dispositivo %1 foi desencriptado</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="459"/>
        <source>Decrypt disk</source>
        <translation>Desencriptar disco</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="463"/>
        <source>Decrypt failed</source>
        <translation>Falha ao desencriptar</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="464"/>
        <source>Device %1 is under encrypting, please decrypt after encryption finished.</source>
        <translation>O dispositivo %1 está em processo de criptografia, por favor, descriptografe após a criptografia ser concluída.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="469"/>
        <source>Device %1 Decrypt failed, please see log for more information.(%2)</source>
        <translation>Falha ao desencriptar dispositivo %1, por favor verifique o relatório de erro para mais informação. (%2)</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="547"/>
        <source>Device is not fully decrypted, please finish decryption before access.</source>
        <translation>O dispositivo não está totalmente descriptografado, por favor, conclua a descriptografia antes do acesso.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="554"/>
        <source>Unlocking device failed</source>
        <translation>Falha ao desbloquear o dispositivo</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="555"/>
        <source>Please click the right disk menu "Continue partition encryption" to complete partition encryption.</source>
        <translation>Por favor, clique no menu do disco direito "Continuar criptografia da partição" para concluir a criptografia da partição.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="331"/>
        <source>TPM status is abnormal, please use the recovery key to unlock it</source>
        <translation>TPM em estado anormal, por favor use a chave de recuperação para desbloquear</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="357"/>
        <source>Wrong PIN</source>
        <translation>PIN errado</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="359"/>
        <source>Wrong passphrase</source>
        <translation>Senha errada</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="361"/>
        <source>TPM error</source>
        <translation>Erro de TPM</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.cpp" line="363"/>
        <source>Please use recovery key to unlock device.</source>
        <translation>Por favor introduza a chave de recuperação para desbloquear dispositivo</translation>
    </message>
</context>
<context>
    <name>dfmplugin_diskenc::UnlockPartitionDialog</name>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/unlockpartitiondialog.cpp" line="51"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/unlockpartitiondialog.cpp" line="52"/>
        <source>Unlock</source>
        <translation>Desbloquear</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/unlockpartitiondialog.cpp" line="81"/>
        <source>Unlock encryption partition</source>
        <translation>Desbloquear partição de encriptação</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/unlockpartitiondialog.cpp" line="85"/>
        <source>Unlock by recovery key</source>
        <translation>Desbloquear com chave de recuperação</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/unlockpartitiondialog.cpp" line="90"/>
        <source>Unlock by passphrase</source>
        <translation>Desbloquear com senha</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/unlockpartitiondialog.cpp" line="91"/>
        <source>Unlock by PIN</source>
        <translation>Desbloquear com PIN</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/unlockpartitiondialog.cpp" line="93"/>
        <source>Please input recovery key to unlock device</source>
        <translation>Por favor introduza a chave de recuperação para desbloquear dispositivo</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/unlockpartitiondialog.cpp" line="99"/>
        <source>Please input passphrase to unlock device</source>
        <translation>Por favor introduza a senha para desbloquear dispositivo</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/unlockpartitiondialog.cpp" line="102"/>
        <source>Please input PIN to unlock device</source>
        <translation>Por favor introduza PIN para desbloquear dispositivo</translation>
    </message>
    <message>
        <location filename="../../src/plugins/filemanager/dfmplugin-disk-encrypt-entry/gui/unlockpartitiondialog.cpp" line="115"/>
        <source>Recovery key is not valid!</source>
        <translation>Chave de recuperação inválida!</translation>
    </message>
</context>
</TS>
